Description Usage Arguments Value
View source: R/vertical_merge.R
Vertically merge a set of data bricks
1 2 3 4 5 6 7 8 |
data_bricks |
Set of data bricks:
A tibble with a list column called |
selections |
TRUE/character vector:
|
diagnostics |
This can either be a logical (TRUE/FALSE) or it can be a character vector listing the diagnostics to be performed: TRUE - perform all diagnostics FALSE - perform no diagnostics Character vector:
|
keep_diagnostics |
TRUE/FALSE. Should diagnostic summary information be stored as an attribute of the output dataset,
which can be viewed, or extracted wholesale, using |
add_metadata |
TRUE/FALSE/character vector:
|
coverage |
A list of named character vectors, this list should follow
a pattern of:
list("metadata_column" = c(expected_values))
Essentially this faccilitates a diagnostic check that the metadata column
contains all the values listed in expected values.
A helper function |
A tibble/dataframe that contains a vertical merger of all of the dataframes in the supplied data_brick object. Optionally, it contains attributes:
"name_diagnostics" - A dataframe containing rows for each variable and columns containing information about any NA-padding that occured (i.e. due to the variable being missing)
"type_diagnostics" - A dataframe containig rows for each variable and columns containing information about the type of the variable and any conversions that took place.
"missingness" - A dataframe containing rows for each variable, and missingn diagnostic information for that variable.
"coverage" - A dataframe with diagnostic information about any missing coverage in the source files.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.